@@ -11,7 +11,8 @@ import {
 import {
   isBooleanAttr,
   isEnumeratedAttr,
-  isFalsyAttrValue
+  isFalsyAttrValue,
+  convertEnumeratedValue
 } from 'web/util/attrs'
 
 import { isSSRUnsafeAttr } from 'web/server/util'
@@ -24,6 +25,10 @@ export default function renderAttrs (node: VNodeWithData): string {
   if (isUndef(opts) || opts.Ctor.options.inheritAttrs !== false) {
     let parent = node.parent
     while (isDef(parent)) {
+      // Stop fallthrough in case parent has inheritAttrs option set to false
+      if (parent.componentOptions && parent.componentOptions.Ctor.options.inheritAttrs === false) {
+        break;
+      }
       if (isDef(parent.data) && isDef(parent.data.attrs)) {
         attrs = extend(extend({}, attrs), parent.data.attrs)
       }
@@ -54,7 +59,7 @@ export function renderAttr (key: string, value: string): string {
       return ` ${key}="${key}"`
     }
   } else if (isEnumeratedAttr(key)) {
-    return ` ${key}="${isFalsyAttrValue(value) || value === 'false' ? 'false' : 'true'}"`
+    return ` ${key}="${escape(convertEnumeratedValue(key, value))}"`
   } else if (!isFalsyAttrValue(value)) {
     return ` ${key}="${escape(String(value))}"`
   }
