@@ -9,7 +9,7 @@ function parseAttrName (name: string): string {
   return camelize(name.replace(bindRE, ''))
 }
 
-export function preTransformVBind (el: ASTElement, options: WeexCompilerOptions) {
+export function preTransformVBind (el: ASTElement) {
   for (const attr in el.attrsMap) {
     if (bindRE.test(attr)) {
       const name: string = parseAttrName(attr)
