@@ -1,7 +1,9 @@
-var alias = require('../../scripts/alias')
-var webpack = require('webpack')
+const alias = require('../../scripts/alias')
+const featureFlags = require('../../scripts/feature-flags')
+const webpack = require('webpack')
 
-var webpackConfig = {
+const webpackConfig = {
+  mode: 'development',
   resolve: {
     alias: alias
   },
@@ -18,9 +20,9 @@ var webpackConfig = {
     new webpack.DefinePlugin({
       __WEEX__: false,
       'process.env': {
-        NODE_ENV: '"development"',
         TRANSITION_DURATION: process.env.CI ? 100 : 50,
-        TRANSITION_BUFFER: 10
+        TRANSITION_BUFFER: 10,
+        ...featureFlags
       }
     })
   ],
